ComputeEnvironment

Enum ComputeEnvironment 

pub enum ComputeEnvironment {
Show 20 variants AwsEc2, AwsEcs, AwsLambda, AwsKubernetes, AwsNomad, AzureContainerApps, AzureContainerAppsJob, AzureContainerInstance, AzureKubernetes, AzureVM, AzureNomad, GcpCloudRunGen1, GcpCloudRunGen2, GcpCloudRunJob, GcpComputeEngine, GcpKubernetes, GcpNomad, Kubernetes, Nomad, Qemu,
}
Supported compute environments that can be detected by this crate

Variants



AwsEc2

Amazon Elastic Compute Cloud (EC2)



AwsEcs

Amazon Elastic Container Service (ECS)



AwsLambda

AWS Lambda



AwsKubernetes

Kubernetes on AWS



AwsNomad

Nomad on AWS



AzureContainerApps

Azure Containers Apps



AzureContainerAppsJob

Azure Container Apps Job



AzureContainerInstance

Azure Container Instance



AzureKubernetes

Kubernetes on Azure



AzureVM

Azure VM



AzureNomad

Nomad on Azure



GcpCloudRunGen1

Google Cloud Run (Gen1)



GcpCloudRunGen2

Google Cloud Run (Gen2)



GcpCloudRunJob

Google Cloud Run (Job)



GcpComputeEngine

Google Compute Engine



GcpKubernetes

Kubernetes on Google Cloud



GcpNomad

Nomad on Google Cloud



Kubernetes

Kubernetes



Nomad

Nomad



Qemu

QEMU

Implementations

Source

impl ComputeEnvironment

pub fn as_str(&self) -> &'static str

Static str representation of the ComputeEnvironment

pub fn platform_code(&self) -> &'static str

Compute Platform code

This corresponds to the cloud.platform attribute in OpenTelemetry semantic conventions where possible.

For Kubernetes on Cloud Providers, this always assumes that someone is using the corresponding managed service (e.g. AWS EKS, AKS, or GKE).

This may also return one of the following values for some environments:

  • kubernetes
  • nomad
  • qemu

See https://opentelemetry.io/docs/specs/semconv/attributes-registry/cloud/

pub fn cloud_provider(&self) -> Option<CloudProvider>

CloudProvider for this compute environment